@@ -1,8 +1,8 @@
 from severino.sdk.airflow import Airflow
 from severino.sdk.hub_distance import HubDistance, HubDistanceCEP
 from severino.sdk.internal_recruitment import MindsightReminder, Movement, Stage
-from severino.sdk.mail_carrier import MailCarrier
+from severino.sdk.mail_carrier import MailCarrier, MailCarrierTemplate
 from severino.sdk.reports_of_pcds_in_admission import ReminderReportsOfPcdsInAdmission
 from severino.sdk.rescission_workflow import RescissionWorkflow
 from severino.sdk.store_data import StoreData, StoreDataTmp
-from severino.sdk.vagas_dot_com import VagasDotComBot
+from severino.sdk.vagas_dot_com import VagasDotComBot, VagasDotComCandidateMigration
