@@ -42,6 +42,7 @@ class MailCarrier:
         subject: str = "",
         context_vars: dict = {},
         files: list = [],
+        tag: str = None,
     ):
         """Send emails using Severino.
 
@@ -54,7 +55,8 @@ class MailCarrier:
             reply_to (list, optional): A list of recipient addresses used in the “Reply-To” header when sending the email.
             subject (str, optional): The subject line of the email.
             context_vars (dict, optional): An object containing key and values ​​that will be used by the template.
-            files (list, optional): A list containing the files that will be sent together to the email. E.g: [{"name": "file.pdf", "content": "PCFkb2N0eXBlIGh0bWw+..."}]
+            files (list, optional): A list containing the files that will be sent together to the email. E.g: [{"name": "file.pdf", "file": "PCFkb2N0eXBlIGh0bWw+..."}]
+            tag (str, optional): You can add a tag to find this email in the future.
         """
 
         data = {
@@ -66,6 +68,7 @@ class MailCarrier:
             "from_connection": from_connection,
             "template_name": template_name,
             "context_vars": context_vars,
+            "tag": tag,
         }
 
         if files:
@@ -152,6 +155,7 @@ class MailCarrierTemplate:
 
     def update(self, template_name: str, template_path: str):
         template_data = None
+        new = False
 
         check_if_exists = self.http.get(
             url=f"{self.severino_api_url}{self.path}/", params={"name": template_name}
@@ -165,6 +169,7 @@ class MailCarrierTemplate:
                     "base64_html": self.__get_file(template_path),
                 },
             ).json()
+            new = True
 
         if not template_data:
             template_data = self.http.put(
@@ -175,7 +180,12 @@ class MailCarrierTemplate:
                 },
             ).json()
 
-        print("\x1b[6;30;42m" + " Template created/updated successfully " + "\x1b[0m")
+        if new:
+            print("\x1b[6;30;42m" + " Template created successfully " + "\x1b[0m")
+            return
+
+        print("\x1b[6;30;42m" + " Template updated successfully " + "\x1b[0m")
+        return
 
     def delete(self, template_name):
         check_if_exists = self.http.get(
