@@ -1,6 +1,7 @@
 from datetime import datetime
 
 from severino.sdk.helpers.http_requests import Http
+from severino.sdk.helpers.pagination import PaginationControls
 from severino.settings import SEVERINO_API_URL
 
 
@@ -41,7 +42,10 @@ class ReminderReportsOfPcdsInAdmission:
         Returns:
             _type_: _description_
         """
-        return self.http.get(url=f"{self.severino_api_url}{self.path}/", params=filters)
+        response = self.http.get(
+            url=f"{self.severino_api_url}{self.path}/", params=filters
+        )
+        return PaginationControls(response)
 
     def update(
         self,
